clear all
%subjID = 'm00027';
subjID = 'subj11';
ch = 44;
mov_ind = 1;
movie_path = '../movie_data_exp1/';
load([movie_path '/movie_event_times'])
%data_path = '../physiology_data_exp1/';
data_path = '../neurophysiology_data_exp1/';

sessionIDs = {'Session1', 'Session2', 'Session3', 'Session4'};

%% Load the data across all sessions
mov_filt = [];
for s = 1:4
sessionID = sessionIDs{s};
session_dir = [data_path subjID '/' sessionID ];
if exist(session_dir)
%% change frequency band here (_bb, _hg, _lg, _alpha)
load([session_dir '/movie_trials_bb.mat'])
movs = {mov1_filt_bb, mov2_filt_bb, mov3_filt_bb};
mov_filt = [mov_filt movs{mov_ind}];
end
end

time_length = round(11950*sr);
plot_int = 1:1/sr:11950;
ntrials = length(mov_filt);
mov_filt_mat = [];
 
for trial = 1:ntrials
    if ~isempty(mov_filt{trial})
        mov_filt_trial = mov_filt{trial}(ch,1:time_length);     
        mov_filt_mat = [mov_filt_mat; mov_filt_trial];
    end
end

%% plot 2b
figure
title(sprintf('Movie %s, Channel %s',  num2str(mov_ind), num2str(ch)))

subplot(3,2,1)
%subplot('Position', [.35 .7 .2 .216]);
hold on
pcolor(plot_int,1:size(mov_filt_mat,1),mov_filt_mat); 
shading flat;
load colorMapRedBlue.mat
set(gcf,'colormap',colorMap);
set(gca, 'Clim', [-250 250]);

plot([movie_event_times_ms{1}(5) movie_event_times_ms{1}(5)], [1 size(mov_filt_mat,1)],...
    'k', 'LineWidth', 2)
ylim([1 size(mov_filt_mat,1)])
xlim([movie_event_times_ms{1}(5)-1000 movie_event_times_ms{1}(5)+2000])
set(gca, 'FontSize', 14)
ylabel('Trial # ')
box off
h = colorbar;
ylabel(h,'IFP (uV)');
%% Plot 2c
subplot(3,2,[3 4]);
hold on
for i = 1:size(mov_filt_mat,1)
    h2a = plot(plot_int,mov_filt_mat(i,:), 'Color', [.5 .5 .5], 'DisplayName', ' 0.3');
    h2a.Color(4)=0.2;  % 80% transparent
end

for times = 1:length(movie_event_times_ms{mov_ind})    
    plot([movie_event_times_ms{mov_ind}(times), movie_event_times_ms{mov_ind}(times)],...
        [-500, 500], 'k--', 'LineWidth', 1)
end
    
plot(plot_int,mean(mov_filt_mat) , 'k', 'LineWidth', 1.5)
axis([0,12000,-250,250])

ylabel('IFP (uV) ')
box off
ax = gca;
ax.TickDir = 'out';
ax.FontSize = 14;

%% Calculate correlation across repetitions
for t = 1:size(mov_filt_mat,2)-49
    tmp = corrcoef(mov_filt_mat(:,t:t+49)');
    tmp_tril = tril(tmp,-1);
    tmp_tril = tmp_tril(find(tmp_tril));
    correl_ch(t+49) = mean(tmp_tril(:));
    std_correl_ch(t+49) = std(tmp_tril(:))./sqrt(length(tmp_tril(:)));
end

%% Plot 2D
subplot(3,2,[5 6])
hold on
shadedErrorBar(plot_int,correl_ch, 2*std_correl_ch,{'-','Color',[0 0 0],'LineWidth',2},1);
for times = 1:length(movie_event_times{mov_ind})
    
    plot([movie_event_times_ms{mov_ind}(times), movie_event_times_ms{mov_ind}(times)],...
        [-0.2, 0.8], 'k--', 'LineWidth', 1)
end

axis([0,12000,-0.2,0.8])
xlabel(' Time from movie onset (ms) ')
ylabel(' Correlation (r) ')
box off
ax = gca;
ax.TickDir = 'out';
ax.FontSize = 14;
%

